==> pure-uikit-1.6.21.tgz: package/cdn/components/table/table.component.js <==
import {
  PTable
} from "../../chunks/chunk.WSDOO7UQ.js";
import "../../chunks/chunk.36U7VCWI.js";
import "../../chunks/chunk.OBOC5VK3.js";
import "../../chunks/chunk.3NX2O2F6.js";
import "../../chunks/chunk.OLFFNBL2.js";
import "../../chunks/chunk.ZXLJ3AYV.js";
import "../../chunks/chunk.LPAJ3AQZ.js";
import "../../chunks/chunk.PXZP76RL.js";
import "../../chunks/chunk.QBNYCPPW.js";
import "../../chunks/chunk.CIYRWWJR.js";
import "../../chunks/chunk.QRAFSN4E.js";
import "../../chunks/chunk.TQQ6S3EH.js";
import "../../chunks/chunk.MPVB7OKZ.js";
import "../../chunks/chunk.GS2KJRKO.js";
import "../../chunks/chunk.VA36342L.js";
import "../../chunks/chunk.NYJ7YDN4.js";
import "../../chunks/chunk.VD46C5DT.js";
import "../../chunks/chunk.VX3FXWFR.js";
import "../../chunks/chunk.F5ABMK3Q.js";
import "../../chunks/chunk.RPBNCTJM.js";
import "../../chunks/chunk.MCGRNRTU.js";
import "../../chunks/chunk.JK75R3VQ.js";
import "../../chunks/chunk.NOWCQZBS.js";
import "../../chunks/chunk.SEMHJAM4.js";
import "../../chunks/chunk.BBWZSNKY.js";
import "../../chunks/chunk.6JBGXCYU.js";
import "../../chunks/chunk.P5XYZBWS.js";
import "../../chunks/chunk.ECQOIAS7.js";
import "../../chunks/chunk.PGG27OMY.js";
import "../../chunks/chunk.IQ5OJYFT.js";
import "../../chunks/chunk.SW6OGP3X.js";
import "../../chunks/chunk.BQKFAAZ3.js";
import "../../chunks/chunk.HE2R23FK.js";
import "../../chunks/chunk.F6XYW4W5.js";
import "../../chunks/chunk.B4BZKR24.js";
import "../../chunks/chunk.S7GYYU7Z.js";
import "../../chunks/chunk.V7W45QBZ.js";
import "../../chunks/chunk.DQNILPUT.js";
import "../../chunks/chunk.MLXUTV4G.js";
import "../../chunks/chunk.A56LY5J2.js";
import "../../chunks/chunk.OZEBCGEZ.js";
import "../../chunks/chunk.3C33BQBP.js";
import "../../chunks/chunk.4AVCUYNK.js";
import "../../chunks/chunk.K6K6S6E6.js";
import "../../chunks/chunk.UYULJY2S.js";
import "../../chunks/chunk.SLZ4BTR5.js";
import "../../chunks/chunk.LLVIMK7X.js";
import "../../chunks/chunk.CJEOGOHE.js";
import "../../chunks/chunk.ZQRLKOUP.js";
import "../../chunks/chunk.H6OFD2KT.js";
import "../../chunks/chunk.ZLOL37LW.js";
import "../../chunks/chunk.FA5RT4K4.js";
import "../../chunks/chunk.GGT2JZPZ.js";
import "../../chunks/chunk.DNSDK7ZG.js";
import "../../chunks/chunk.XHSHLALN.js";
import "../../chunks/chunk.KIILAQWQ.js";
export {
  PTable as default
};

==> pure-uikit-1.6.22.tgz: package/cdn/components/table/table.component.js <==
import {
  PTable
} from "../../chunks/chunk.PA5JBIM7.js";
import "../../chunks/chunk.36U7VCWI.js";
import "../../chunks/chunk.OBOC5VK3.js";
import "../../chunks/chunk.KEAEHH4C.js";
import "../../chunks/chunk.GXNUUBFF.js";
import "../../chunks/chunk.ZXLJ3AYV.js";
import "../../chunks/chunk.I5TYFL4Z.js";
import "../../chunks/chunk.PXZP76RL.js";
import "../../chunks/chunk.QBNYCPPW.js";
import "../../chunks/chunk.JBRDJZPQ.js";
import "../../chunks/chunk.UVABLVHF.js";
import "../../chunks/chunk.TQQ6S3EH.js";
import "../../chunks/chunk.RVKSYSJV.js";
import "../../chunks/chunk.GS2KJRKO.js";
import "../../chunks/chunk.VA36342L.js";
import "../../chunks/chunk.NYJ7YDN4.js";
import "../../chunks/chunk.HZLJGPIC.js";
import "../../chunks/chunk.UBR4JMY6.js";
import "../../chunks/chunk.F5ABMK3Q.js";
import "../../chunks/chunk.RPBNCTJM.js";
import "../../chunks/chunk.ALP3ZK4X.js";
import "../../chunks/chunk.JK75R3VQ.js";
import "../../chunks/chunk.NOWCQZBS.js";
import "../../chunks/chunk.3IWIPZ63.js";
import "../../chunks/chunk.BBWZSNKY.js";
import "../../chunks/chunk.6JBGXCYU.js";
import "../../chunks/chunk.RWC6AEIC.js";
import "../../chunks/chunk.ECQOIAS7.js";
import "../../chunks/chunk.PGG27OMY.js";
import "../../chunks/chunk.IQ5OJYFT.js";
import "../../chunks/chunk.SW6OGP3X.js";
import "../../chunks/chunk.VNTNGXEE.js";
import "../../chunks/chunk.HE2R23FK.js";
import "../../chunks/chunk.F6XYW4W5.js";
import "../../chunks/chunk.B4BZKR24.js";
import "../../chunks/chunk.S7GYYU7Z.js";
import "../../chunks/chunk.V7W45QBZ.js";
import "../../chunks/chunk.DQNILPUT.js";
import "../../chunks/chunk.MLXUTV4G.js";
import "../../chunks/chunk.3C33BQBP.js";
import "../../chunks/chunk.4AVCUYNK.js";
import "../../chunks/chunk.K6K6S6E6.js";
import "../../chunks/chunk.A56LY5J2.js";
import "../../chunks/chunk.OZEBCGEZ.js";
import "../../chunks/chunk.O23VDN3Y.js";
import "../../chunks/chunk.SLZ4BTR5.js";
import "../../chunks/chunk.LLVIMK7X.js";
import "../../chunks/chunk.CJEOGOHE.js";
import "../../chunks/chunk.ZQRLKOUP.js";
import "../../chunks/chunk.H6OFD2KT.js";
import "../../chunks/chunk.FA5RT4K4.js";
import "../../chunks/chunk.6XKJHIKA.js";
import "../../chunks/chunk.DNSDK7ZG.js";
import "../../chunks/chunk.ZLOL37LW.js";
import "../../chunks/chunk.XHSHLALN.js";
import "../../chunks/chunk.KIILAQWQ.js";
export {
  PTable as default
};
